==> carbon-component-mapper-3.11.4.tgz: package/esm/text-field/text-field.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import TextInput from "carbon-components-react/es/components/TextInput/TextInput.js";
import NumberInput from "carbon-components-react/es/components/NumberInput/NumberInput.js";
import prepareProps from '../prepare-props';

var TextField = function TextField(props) {
  var _useFieldApi = useFieldApi(prepareProps(props)),
      input = _useFieldApi.input,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      labelText = _useFieldApi.labelText,
      rest = _objectWithoutProperties(_useFieldApi, ["input", "meta", "validateOnMount", "labelText"]);

  var Component = input.type === 'number' ? NumberInput : TextInput;

  var setValue = function setValue(e, input) {
    return input.type === 'number' ? e.imaginaryTarget.value : e.target.value;
  };

  var invalid = (meta.touched || validateOnMount) && (meta.error || meta.submitError);
  var warn = (meta.touched || validateOnMount) && meta.warning;
  return /*#__PURE__*/React.createElement(Component, _extends({}, input, {
    key: input.name,
    id: input.name,
    invalid: Boolean(invalid),
    invalidText: invalid || '',
    warn: Boolean(warn),
    warnText: warn || '',
    onChange: function onChange(e) {
      return input.onChange(setValue(e, input));
    }
  }, input.type === 'number' ? {
    label: labelText
  } : {
    labelText: labelText
  }, rest));
};

TextField.propTypes = {
  isDisabled: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  labelText: PropTypes.node,
  description: PropTypes.node
};
export default TextField;

==> carbon-component-mapper-3.17.0.tgz: package/esm/text-field/text-field.js <==
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["input", "meta", "validateOnMount", "labelText"];
import React from 'react';
import PropTypes from 'prop-types';
import useFieldApi from "@data-driven-forms/react-form-renderer/use-field-api";
import TextInput from "carbon-components-react/es/components/TextInput/TextInput.js";
import NumberInput from "carbon-components-react/es/components/NumberInput/NumberInput.js";
import prepareProps from '../prepare-props';

var TextField = function TextField(props) {
  var _useFieldApi = useFieldApi(prepareProps(props)),
      input = _useFieldApi.input,
      meta = _useFieldApi.meta,
      validateOnMount = _useFieldApi.validateOnMount,
      labelText = _useFieldApi.labelText,
      rest = _objectWithoutProperties(_useFieldApi, _excluded);

  var Component = input.type === 'number' ? NumberInput : TextInput;

  var setValue = function setValue(e, input) {
    return input.type === 'number' ? e.imaginaryTarget.value : e.target.value;
  };

  var invalid = (meta.touched || validateOnMount) && (meta.error || meta.submitError);
  var warn = (meta.touched || validateOnMount) && meta.warning;
  return /*#__PURE__*/React.createElement(Component, _extends({}, input, {
    key: input.name,
    id: input.name,
    invalid: Boolean(invalid),
    invalidText: invalid || '',
    warn: Boolean(warn),
    warnText: warn || '',
    onChange: function onChange(e) {
      return input.onChange(setValue(e, input));
    }
  }, input.type === 'number' ? {
    label: labelText
  } : {
    labelText: labelText
  }, rest));
};

TextField.propTypes = {
  isDisabled: PropTypes.bool,
  isReadOnly: PropTypes.bool,
  isRequired: PropTypes.bool,
  label: PropTypes.node,
  labelText: PropTypes.node,
  description: PropTypes.node
};
export default TextField;
